@@ -3,6 +3,6 @@ from python_helper.api.src.service import LogHelper as log
 from python_helper.api.src.service import ObjectHelper, SettingHelper, StringHelper, EnvironmentHelper, ReflectionHelper, RandomHelper
 from python_helper.api.src.domain import Constant
 from python_helper.api.src.annotation.EnvironmentAnnotation import EnvironmentVariable
-from python_helper.api.src.annotation import MethodAnnotation
+from python_helper.api.src.annotation.TestAnnotation import Test
 from python_helper.api.src.annotation.MethodAnnotation import Method, Function, FunctionThrough
 from python_helper.api.src.helper import ObjectHelperHelper, SettingHelperHelper, SettingHelperHelper, LogHelperHelper, RandomHelperHelper
